10 REM WHILWEND.BAS -- Test WHILE-WEND Loops
20 PRINT "START" 
30 LET X = 0 
40 WHILE X < 25 
50 PRINT "x is ";X 
60 LET X = X + 1 
70 LET Y = 0 
80 WHILE Y < 2 
90 PRINT "y is "; Y 
100 LET Y = Y + 1 
110 WEND 
120 WEND 
130 PRINT "END" 
