
Sub Prior
   Print "This is a subroutine prior to MAIN."
   Print "This should not print."
End Sub

Sub Main
   Print "This is the MAIN subroutine."
   Print "This should print."
End Sub

Sub Subsequent
   Print "This is a subroutine subsequent to MAIN."
   Print "This should not print."
End Sub


