
rem ----------------------------------------------------
rem SnglFunc.BAS
rem ----------------------------------------------------

Print "SnglFunc.BAS -- Test Single-Line User-defined Function Statement"
Print

Def Sum( x, y ) = x + y

Print
Print "The sum of 6 and 4 is "; Sum( 6, 4 )

Print "Did it work properly?"
End
