
rem -------------------------------------------------
rem mlifthen.bas -- Test MultiLine IF-THEN statement
rem -------------------------------------------------

Print "MLIFTHEN.BAS -- Test MultiLine IF-THEN-ELSE Constructions"

If 3 = 4 then
   Print "The Condition is true."
   Print "And it still is true."
Else
   Print "The condition is false."
   Print "And it still is false."
End If

Print "This concludes our test."
