10 REM END.BAS -- Test END Statement 
20 PRINT "END.BAS -- Test END Statement" 
30 PRINT "If the program ends after this line, END worked OK." 
40 END 
50 PRINT "But if this line printed, then it did not work." 
60 END 
