10 print "ON.BAS -- Test ON...GOTO Statement"
20 input "Enter a number 1-5:";n
30 on n goto 40, 60, 80, 100, 120
40 print "You entered 1"
50 goto 140
60 print "You entered 2"
70 goto 140
80 print "You entered 3"
90 goto 140
100 print "You entered 4"
110 goto 140
120 print "You entered 5"
130 goto 140
140 end
