10 REM FORNEXT.BAS -- Test FOR-NEXT Statements 
20 REM 
30 PRINT "FORNEXT.BAS: Test FOR-NEXT Statements" 
40 PRINT "A FOR-NEXT Loop with STEP statement:" 
50 FOR i=1 to 30 step 2 
60 PRINT "FOR: i is ";i 
70 NEXT i 
80 REM 
90 PRINT "A FOR-NEXT Loop without STEP statement:" 
100 FOR i = 2 to 7 
110 PRINT "FOR: i is ";i 
120 NEXT i 
130 END 
