10 REM INPUT.BAS -- Test INPUT Statement 
20 PRINT "INPUT.BAS -- Test INPUT Statement" 
30 REM 
40 INPUT "Input string, number: "; s$, n 
50 PRINT "The string is: ";s$ 
60 PRINT "The number is: ";n 
70 END 
