10 REM STOP.BAS -- Test STOP Statement 
20 PRINT "STOP.BAS -- Test STOP Statement" 
30 PRINT "If the program is interrupted after this line, STOP worked OK"
40 STOP 
50 PRINT "But if this line printed, then it did not work." 
60 END 
